@@ -11,6 +11,12 @@
 
 #include <QObject>
 
+class DatabaseInterface;
+class MediaPlayList;
+class QAbstractItemModelTester;
+class QSignalSpy;
+class TracksListener;
+
 class MediaPlayListTest : public QObject, public DatabaseTestData
 {
 
@@ -26,6 +32,10 @@ private Q_SLOTS:
 
     void initTestCase();
 
+    void init();
+
+    void cleanup();
+
     void simpleInitialCase();
 
     void enqueueAlbumCase();
@@ -42,6 +52,8 @@ private Q_SLOTS:
 
     void enqueueEmpty();
 
+    void enqueueAtIndex();
+
     void removeFirstTrackOfAlbum();
 
     void testTrackBeenRemoved();
@@ -74,9 +86,26 @@ private Q_SLOTS:
 
     void crashOnEnqueue();
 
-};
+private:
 
-class MediaPlayList;
+    MediaPlayList *mPlayList = nullptr;
+    QAbstractItemModelTester *mModelTester = nullptr;
+    DatabaseInterface *mDatabaseContent = nullptr;
+    TracksListener *mListener = nullptr;
+
+    QSignalSpy *mRowsAboutToBeMovedSpy = nullptr;
+    QSignalSpy *mRowsAboutToBeRemovedSpy = nullptr;
+    QSignalSpy *mRowsAboutToBeInsertedSpy = nullptr;
+    QSignalSpy *mRowsMovedSpy = nullptr;
+    QSignalSpy *mRowsRemovedSpy = nullptr;
+    QSignalSpy *mRowsInsertedSpy = nullptr;
+    QSignalSpy *mDataChangedSpy = nullptr;
+
+    QSignalSpy *mNewEntryInListSpy = nullptr;
+    QSignalSpy *mNewTrackByNameInListSpy = nullptr;
+    QSignalSpy *mNewUrlInListSpy = nullptr;
+
+};
 
 class CrashEnqueuePlayList : public QObject
 {
