@@ -13,6 +13,8 @@
 #include <QImage>
 #include <QMimeDatabase>
 
+namespace
+{
 class AsyncImageResponse : public QQuickImageResponse, public QRunnable
 {
     Q_OBJECT
@@ -46,7 +48,7 @@ public:
 
         mErrorMessage = QLatin1String{""};
 
-        auto extractors = ec.fetchExtractors(fileMimeType);
+        const auto extractors = ec.fetchExtractors(fileMimeType);
         for (const auto& ex : extractors) {
             ex->extract(&result);
         }
@@ -89,6 +91,7 @@ public:
     QSize mRequestedSize;
     QImage mCoverImage;
 };
+}
 
 EmbeddedCoverageImageProvider::EmbeddedCoverageImageProvider()
     : QQuickAsyncImageProvider()
