@@ -12,21 +12,26 @@
 #include "elisaLib_export.h"
 
 #include <QObject>
+#include <QQmlEngine>
 #include <QSharedPointer>
+
 #include <memory>
 
+#include "manageaudioplayer.h"
+#include "manageheaderbar.h"
+#include "managemediaplayercontrol.h"
+
 class MediaPlayer2Player;
 class MediaPlayer2;
 class MediaPlayListProxyModel;
-class ManageAudioPlayer;
-class ManageMediaPlayerControl;
-class ManageHeaderBar;
 class AudioWrapper;
 
 class ELISALIB_EXPORT Mpris2 : public QObject
 {
     Q_OBJECT
 
+    QML_ELEMENT
+
     Q_PROPERTY(QString playerName
                READ playerName
                WRITE setPlayerName
@@ -66,19 +71,19 @@ public:
     explicit Mpris2(QObject* parent = nullptr);
     ~Mpris2() override;
 
-    QString playerName() const;
+    [[nodiscard]] QString playerName() const;
 
-    MediaPlayListProxyModel* playListModel() const;
+    [[nodiscard]] MediaPlayListProxyModel* playListModel() const;
 
-    ManageAudioPlayer* audioPlayerManager() const;
+    [[nodiscard]] ManageAudioPlayer* audioPlayerManager() const;
 
-    ManageMediaPlayerControl* manageMediaPlayerControl() const;
+    [[nodiscard]] ManageMediaPlayerControl* manageMediaPlayerControl() const;
 
-    ManageHeaderBar* headerBarManager() const;
+    [[nodiscard]] ManageHeaderBar* headerBarManager() const;
 
-    AudioWrapper* audioPlayer() const;
+    [[nodiscard]] AudioWrapper* audioPlayer() const;
 
-    bool showProgressOnTaskBar() const;
+    [[nodiscard]] bool showProgressOnTaskBar() const;
 
 public Q_SLOTS:
 
